# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2023-05-08)
### Documentation
* **README:** Removed demo template section ([`8caca28`](https://github.com/educationwarehouse/edwh-locust-plugin/commit/8caca28e4571715fdfe315d7d123410adf1e61ab))

## v0.1.0 (2023-05-08)
### Feature
* Added initial code (copied from ontwikkelstraat/tasks.py) ([`7d1555a`](https://github.com/robinvandernoord/edwh-locust-plugin/commit/7d1555a08ce2328918b42989c89081eaeebcfa6a))